declare module "ej/core" {
    import { EventEmitter, QueryList, Type, ElementRef, SimpleChange, ChangeDetectorRef } from '@angular/core';
    export { ContentChild, Type, forwardRef } from '@angular/core';
    export interface IParentTag {
        tags: Array<any>;
    }
    export interface IChildChange {
        index: number;
        change: any;
    }
    export interface IChangeSet {
        [key: string]: Array<IChildChange>;
    }
    /** Internal Helpers */
    export class Utils {
        static IterateAndGetChanges(obj: IParentTag): IChangeSet;
        static AngularizeInputs(inputs: Array<string>, twoways: Array<string>): Array<string>;
    }
    export class EJComponents<W, T> implements IParentTag {
        protected name: string;
        protected el: ElementRef;
        protected cdRef: ChangeDetectorRef;
        tags: Array<any>;
        model: T;
        widget: W;
        protected outputs: Array<string>;
        protected twoways: Array<string>;
        protected __shadow: DocumentFragment;
        protected complexProperties: Array<string>;
        private _firstCheck;
        constructor(name: string, el: ElementRef, cdRef: ChangeDetectorRef);
        protected createEvents(events: Array<string>): void;
        protected createTwoways(twoways: Array<string>): void;
        protected addTwoways(prop: any): Function;
        ngAfterContentInit(): void;
        private static bindAndRaiseEvent(instance, model, event);
        ngOnChanges(changes: {
            [key: string]: SimpleChange;
        }): void;
        ngAfterContentChecked(): void;
        ngOnDestroy(): void;
    }
    export class ComplexTagElement {
        recentChanges: any;
        hasChanges: boolean;
        __firstChange: boolean;
        __index: number;
        __valueChange: EventEmitter<any>;
        protected complexProperties: Array<string>;
        property: string;
        __parent: EJComponents<any, any>;
        tags: Array<string>;
        constructor();
        ngOnInit(): void;
        ensureCleanObject(): void;
        ngOnChanges(changes: {
            [key: string]: SimpleChange;
        }): void;
        getChangesAndReset(): any;
        ngAfterContentChecked(): void;
    }
    export class ArrayTagElement<T extends ComplexTagElement> {
        propertyName: string;
        list: Array<T>;
        children: QueryList<T>;
        recentChanges: Array<IChildChange>;
        hasChanges: boolean;
        constructor(propertyName: string);
        ngAfterContentInit(): void;
        ngOnChanges(changes: any): void;
        getList(): T[];
        getChangesAndReset(): Array<IChildChange>;
        ngAfterContentChecked(): void;
    }
    export function CreateComplexDirective(args: {
        selector: string;
        inputs: Array<string>;
        outputs?: Array<string>;
        queries?: {
            [key: string]: any;
        };
    }, ejArgs: any): Type;
    export function CreateArrayTagDirective(property: string, selector: string, type: any): Type;
    export function CreateComponent(name: string, componentArgs: {
        selector: string;
        inputs: Array<string>;
        outputs: Array<string>;
        template: string;
        changeDetection?: any;
        queries: {
            [key: string]: any;
        };
    }, ejArgs: any): Type;
    export function CreateControlValueAccessor(selector: string, component: Type): Type;
}
declare module "ej/accordion.component" {
    import { Type } from "ej/core";
    export var AccordionComponent: Type;
    export const EJ_ACCORDION_COMPONENTS: Type[];
}
declare module "ej/autocomplete.component" {
    import { Type } from "ej/core";
    export var AutocompleteComponent: Type;
    export var AutocompleteValueAccessor: Type;
    export const EJ_AUTOCOMPLETE_COMPONENTS: Type[];
}
declare module "ej/barcode.component" {
    import { Type } from "ej/core";
    export var BarcodeComponent: Type;
    export const EJ_BARCODE_COMPONENTS: Type[];
}
declare module "ej/bulletgraph.component" {
    import { Type } from "ej/core";
    export var QualitativeRangeDirective: any;
    export var QualitativeRangesDirective: any;
    export var QuantitativeScaleSettingsFeatureMeasureDirective: any;
    export var QuantitativeScaleSettingsFeatureMeasuresDirective: any;
    export var BulletGraphComponent: any;
    export const EJ_BULLETGRAPH_COMPONENTS: Type[];
}
declare module "ej/button.component" {
    import { Type } from "ej/core";
    export var ButtonComponent: Type;
    export const EJ_BUTTON_COMPONENTS: Type[];
}
declare module "ej/chart.component" {
    import { Type } from "ej/core";
    export var stripLineDirective: any;
    export var StripLineCollectionDirective: any;
    export var AxisDirective: any;
    export var AxesDirective: any;
    export var TrendlineDirective: any;
    export var TrendlinesDirective: any;
    export var PointDirective: any;
    export var PointsDirective: any;
    export var SeriesDirective: any;
    export var SeriesCollectionDirective: any;
    export var IndicatorDirective: any;
    export var IndicatorsDirective: any;
    export var AnnotationDirective: any;
    export var AnnotationsDirective: any;
    export var PrimaryXAxisStripLineDirective: any;
    export var PrimaryXAxisStripLineCollectionDirective: any;
    export var PrimaryYAxisStripLineDirective: any;
    export var PrimaryYAxisStripLineCollectionDirective: any;
    export var PaletteDirective: any;
    export var PaletteCollectionDirective: any;
    export var ToolbarItemDirective: any;
    export var ToolbarItemsDirective: any;
    export var RowDefinitionDirective: any;
    export var RowDefinitionsDirective: any;
    export var ColumnDefinitionDirective: any;
    export var ColumnDefinitionsDirective: any;
    export var ChartComponent: any;
    export const EJ_CHART_COMPONENTS: Type[];
}
declare module "ej/checkbox.component" {
    import { Type } from "ej/core";
    export var CheckBoxComponent: Type;
    export const EJ_CHECKBOX_COMPONENTS: Type[];
}
declare module "ej/circulargauge.component" {
    import { Type } from "ej/core";
    export var PointerDirective: any;
    export var PointersDirective: any;
    export var LabelDirective: any;
    export var LabelsDirective: any;
    export var TickDirective: any;
    export var TicksDirective: any;
    export var RangeDirective: any;
    export var RangesDirective: any;
    export var StateRangeDirective: any;
    export var StateRangesDirective: any;
    export var IndicatorDirective: any;
    export var IndicatorsDirective: any;
    export var SubGaugeDirective: any;
    export var SubGaugesDirective: any;
    export var CustomLabelDirective: any;
    export var CustomLabelsDirective: any;
    export var ScaleDirective: any;
    export var ScalesDirective: any;
    export var CircularGaugeComponent: any;
    export const EJ_CIRCULARGAUGE_COMPONENTS: Type[];
}
declare module "ej/colorpicker.component" {
    import { Type } from "ej/core";
    export var ColorPickerComponent: Type;
    export var ColorPickerValueAccessor: Type;
    export const EJ_COLORPICKER_COMPONENTS: Type[];
}
declare module "ej/currencytextbox.component" {
    import { Type } from "ej/core";
    export var CurrencyTextboxComponent: Type;
    export var CurrencyTextboxValueAccessor: Type;
    export const EJ_CURRENCYTEXTBOX_COMPONENTS: Type[];
}
declare module "ej/datepicker.component" {
    import { Type } from "ej/core";
    export var DatePickerComponent: Type;
    export var DatePickerValueAccessor: Type;
    export const EJ_DATEPICKER_COMPONENTS: Type[];
}
declare module "ej/datetimepicker.component" {
    import { Type } from "ej/core";
    export var DateTimePickerComponent: Type;
    export var DateTimePickerValueAccessor: Type;
    export const EJ_DATETIMEPICKER_COMPONENTS: Type[];
}
declare module "ej/dialog.component" {
    import { Type } from "ej/core";
    export var DialogComponent: Type;
    export const EJ_DIALOG_COMPONENTS: Type[];
}
declare module "ej/digitalgauge.component" {
    import { Type } from "ej/core";
    export var ItemDirective: any;
    export var ItemsDirective: any;
    export var DigitalGaugeComponent: any;
    export const EJ_DIGITALGAUGE_COMPONENTS: Type[];
}
declare module "ej/dropdownlist.component" {
    import { Type } from "ej/core";
    export var DropDownListComponent: Type;
    export var DropDownListValueAccessor: Type;
    export const EJ_DROPDOWNLIST_COMPONENTS: Type[];
}
declare module "ej/fileexplorer.component" {
    import { Type } from "ej/core";
    export var FileExplorerComponent: Type;
    export const EJ_FILEEXPLORER_COMPONENTS: Type[];
}
declare module "ej/gantt.component" {
    import { Type } from "ej/core";
    export var StriplineDirective: any;
    export var StriplinesDirective: any;
    export var HolidayDirective: any;
    export var HolidaysDirective: any;
    export var SelectedCellIndexDirective: any;
    export var SelectedCellIndexesDirective: any;
    export var EditDialogFieldDirective: any;
    export var EditDialogFieldsDirective: any;
    export var AddDialogFieldDirective: any;
    export var AddDialogFieldsDirective: any;
    export var ColumnDialogFieldDirective: any;
    export var ColumnDialogFieldsDirective: any;
    export var GanttComponent: any;
    export const EJ_GANTT_COMPONENTS: Type[];
}
declare module "ej/grid.component" {
    import { Type } from "ej/core";
    export var ColumnDirective: any;
    export var ColumnsDirective: any;
    export var SummaryColumnDirective: any;
    export var SummaryColumnsDirective: any;
    export var SummaryRowDirective: any;
    export var SummaryRowsDirective: any;
    export var StackedHeaderColumnDirective: any;
    export var StackedHeaderColumnsDirective: any;
    export var StackedHeaderRowDirective: any;
    export var StackedHeaderRowsDirective: any;
    export var GridComponent: any;
    export const EJ_GRID_COMPONENTS: Type[];
}
declare module "ej/kanban.component" {
    import { Type } from "ej/core";
    export var ColumnDirective: any;
    export var ColumnsDirective: any;
    export var KanbanComponent: any;
    export const EJ_KANBAN_COMPONENTS: Type[];
}
declare module "ej/lineargauge.component" {
    import { Type } from "ej/core";
    export var MarkerPointerDirective: any;
    export var MarkerPointersDirective: any;
    export var BarPointerDirective: any;
    export var BarPointersDirective: any;
    export var RangeDirective: any;
    export var RangesDirective: any;
    export var TickDirective: any;
    export var TicksDirective: any;
    export var StateRangeDirective: any;
    export var StateRangesDirective: any;
    export var IndicatorDirective: any;
    export var IndicatorsDirective: any;
    export var LabelDirective: any;
    export var LabelsDirective: any;
    export var CustomLabelDirective: any;
    export var CustomLabelsDirective: any;
    export var ScaleDirective: any;
    export var ScalesDirective: any;
    export var LinearGaugeComponent: any;
    export const EJ_LINEARGAUGE_COMPONENTS: Type[];
}
declare module "ej/listbox.component" {
    import { Type } from "ej/core";
    export var ListBoxComponent: Type;
    export const EJ_LISTBOX_COMPONENTS: Type[];
}
declare module "ej/listview.component" {
    import { Type } from "ej/core";
    export var ItemDirective: any;
    export var ItemsDirective: any;
    export var ListViewComponent: any;
    export const EJ_LISTVIEW_COMPONENTS: Type[];
}
declare module "ej/maskedit.component" {
    import { Type } from "ej/core";
    export var MaskEditComponent: Type;
    export var MaskEditValueAccessor: Type;
    export const EJ_MASKEDIT_COMPONENTS: Type[];
}
declare module "ej/menu.component" {
    import { Type } from "ej/core";
    export var MenuComponent: Type;
    export const EJ_MENU_COMPONENTS: Type[];
}
declare module "ej/numerictextbox.component" {
    import { Type } from "ej/core";
    export var NumericTextboxComponent: Type;
    export var NumericTextboxValueAccessor: Type;
    export const EJ_NUMERICTEXTBOX_COMPONENTS: Type[];
}
declare module "ej/pdfviewer.component" {
    import { Type } from "ej/core";
    export var PdfViewerComponent: Type;
    export const EJ_PDFVIEWER_COMPONENTS: Type[];
}
declare module "ej/percentagetextbox.component" {
    import { Type } from "ej/core";
    export var PercentageTextboxComponent: Type;
    export var PercentageTextboxValueAccessor: Type;
    export const EJ_PERCENTAGETEXTBOX_COMPONENTS: Type[];
}
declare module "ej/pivotgrid.component" {
    import { Type } from "ej/core";
    export var PivotGridComponent: Type;
    export const EJ_PIVOTGRID_COMPONENTS: Type[];
}
declare module "ej/progressbar.component" {
    import { Type } from "ej/core";
    export var ProgressBarComponent: Type;
    export const EJ_PROGRESSBAR_COMPONENTS: Type[];
}
declare module "ej/radialmenu.component" {
    import { Type } from "ej/core";
    export var RadialMenuComponent: Type;
    export const EJ_RADIALMENU_COMPONENTS: Type[];
}
declare module "ej/radiobutton.component" {
    import { Type } from "ej/core";
    export var RadioButtonComponent: Type;
    export var RadioButtonValueAccessor: Type;
    export const EJ_RADIOBUTTON_COMPONENTS: Type[];
}
declare module "ej/rangenavigator.component" {
    import { Type } from "ej/core";
    export var PointDirective: any;
    export var PointsDirective: any;
    export var SeriesDirective: any;
    export var SeriesCollectionDirective: any;
    export var RangeNavigatorComponent: any;
    export const EJ_RANGENAVIGATOR_COMPONENTS: Type[];
}
declare module "ej/rating.component" {
    import { Type } from "ej/core";
    export var RatingComponent: Type;
    export const EJ_RATING_COMPONENTS: Type[];
}
declare module "ej/reportviewer.component" {
    import { Type } from "ej/core";
    export var ReportViewerComponent: Type;
    export const EJ_REPORTVIEWER_COMPONENTS: Type[];
}
declare module "ej/ribbon.component" {
    import { Type } from "ej/core";
    export var PageDirective: any;
    export var ApplicationTabBackstageSettingsPagesDirective: any;
    export var ContentGroupDirective: any;
    export var ContentGroupsDirective: any;
    export var ContentDirective: any;
    export var ContentsDirective: any;
    export var GroupDirective: any;
    export var GroupsDirective: any;
    export var TabDirective: any;
    export var TabsDirective: any;
    export var RibbonComponent: any;
    export const EJ_RIBBON_COMPONENTS: Type[];
}
declare module "ej/rotator.component" {
    import { Type } from "ej/core";
    export var RotatorComponent: Type;
    export const EJ_ROTATOR_COMPONENTS: Type[];
}
declare module "ej/rte.component" {
    import { Type } from "ej/core";
    export var RTEComponent: Type;
    export var RTEValueAccessor: Type;
    export const EJ_RTE_COMPONENTS: Type[];
}
declare module "ej/schedule.component" {
    import { Type } from "ej/core";
    export var ResourceDirective: any;
    export var ResourcesDirective: any;
    export var ScheduleComponent: any;
    export const EJ_SCHEDULE_COMPONENTS: Type[];
}
declare module "ej/scroller.component" {
    import { Type } from "ej/core";
    export var ScrollerComponent: Type;
    export const EJ_SCROLLER_COMPONENTS: Type[];
}
declare module "ej/slider.component" {
    import { Type } from "ej/core";
    export var SliderComponent: Type;
    export const EJ_SLIDER_COMPONENTS: Type[];
}
declare module "ej/splitter.component" {
    import { Type } from "ej/core";
    export var SplitterComponent: Type;
    export const EJ_SPLITTER_COMPONENTS: Type[];
}
declare module "ej/spreadsheet.component" {
    import { Type } from "ej/core";
    export var RangeSettingDirective: any;
    export var RangeSettingsDirective: any;
    export var SheetDirective: any;
    export var SheetsDirective: any;
    export var SpreadsheetComponent: any;
    export const EJ_SPREADSHEET_COMPONENTS: Type[];
}
declare module "ej/tab.component" {
    import { Type } from "ej/core";
    export var TabComponent: Type;
    export const EJ_TAB_COMPONENTS: Type[];
}
declare module "ej/tagcloud.component" {
    import { Type } from "ej/core";
    export var TagCloudComponent: Type;
    export const EJ_TAGCLOUD_COMPONENTS: Type[];
}
declare module "ej/tileview.component" {
    import { Type } from "ej/core";
    export var TileViewComponent: Type;
    export const EJ_TILEVIEW_COMPONENTS: Type[];
}
declare module "ej/timepicker.component" {
    import { Type } from "ej/core";
    export var TimePickerComponent: Type;
    export var TimePickerValueAccessor: Type;
    export const EJ_TIMEPICKER_COMPONENTS: Type[];
}
declare module "ej/togglebutton.component" {
    import { Type } from "ej/core";
    export var ToggleButtonComponent: Type;
    export const EJ_TOGGLEBUTTON_COMPONENTS: Type[];
}
declare module "ej/toolbar.component" {
    import { Type } from "ej/core";
    export var ToolbarComponent: Type;
    export const EJ_TOOLBAR_COMPONENTS: Type[];
}
declare module "ej/tooltip.component" {
    import { Type } from "ej/core";
    export var TooltipComponent: Type;
    export const EJ_TOOLTIP_COMPONENTS: Type[];
}
declare module "ej/treegrid.component" {
    import { Type } from "ej/core";
    export var ColumnDirective: any;
    export var ColumnsDirective: any;
    export var SelectedCellIndexDirective: any;
    export var SelectedCellIndexesDirective: any;
    export var ColumnDialogFieldDirective: any;
    export var ColumnDialogFieldsDirective: any;
    export var TreeGridComponent: any;
    export const EJ_TREEGRID_COMPONENTS: Type[];
}
declare module "ej/treeview.component" {
    import { Type } from "ej/core";
    export var TreeViewComponent: Type;
    export const EJ_TREEVIEW_COMPONENTS: Type[];
}
// declare module "ej/web.all" {
//     export { EJ_GRID_COMPONENTS, GridComponent, ColumnsDirective, ColumnDirective, SummaryColumnsDirective, SummaryColumnDirective, SummaryRowsDirective, SummaryRowDirective, StackedHeaderColumnsDirective, StackedHeaderColumnDirective, StackedHeaderRowsDirective, StackedHeaderRowDirective } from "ej/grid.component";
//     export { EJ_CHART_COMPONENTS, ChartComponent, StripLineCollectionDirective, stripLineDirective, AxesDirective, AxisDirective, TrendlinesDirective, TrendlineDirective, PointsDirective, PointDirective, SeriesCollectionDirective, SeriesDirective, IndicatorsDirective, IndicatorDirective, AnnotationsDirective, AnnotationDirective, PrimaryXAxisStripLineCollectionDirective, PrimaryXAxisStripLineDirective, PrimaryYAxisStripLineCollectionDirective, PrimaryYAxisStripLineDirective, PaletteCollectionDirective, PaletteDirective, ToolbarItemsDirective, ToolbarItemDirective, RowDefinitionsDirective, RowDefinitionDirective, ColumnDefinitionsDirective, ColumnDefinitionDirective } from "ej/chart.component";
//     export { EJ_RANGENAVIGATOR_COMPONENTS, RangeNavigatorComponent, PointsDirective, PointDirective, SeriesCollectionDirective, SeriesDirective } from "ej/rangenavigator.component";
//     export { EJ_BULLETGRAPH_COMPONENTS, BulletGraphComponent, QualitativeRangesDirective, QualitativeRangeDirective, QuantitativeScaleSettingsFeatureMeasuresDirective, QuantitativeScaleSettingsFeatureMeasureDirective } from "ej/bulletgraph.component";
//     export { EJ_CIRCULARGAUGE_COMPONENTS, CircularGaugeComponent, PointersDirective, PointerDirective, LabelsDirective, LabelDirective, TicksDirective, TickDirective, RangesDirective, RangeDirective, StateRangesDirective, StateRangeDirective, IndicatorsDirective, IndicatorDirective, SubGaugesDirective, SubGaugeDirective, CustomLabelsDirective, CustomLabelDirective, ScalesDirective, ScaleDirective } from "ej/circulargauge.component";
//     export { EJ_LINEARGAUGE_COMPONENTS, LinearGaugeComponent, MarkerPointersDirective, MarkerPointerDirective, BarPointersDirective, BarPointerDirective, RangesDirective, RangeDirective, TicksDirective, TickDirective, StateRangesDirective, StateRangeDirective, IndicatorsDirective, IndicatorDirective, LabelsDirective, LabelDirective, CustomLabelsDirective, CustomLabelDirective, ScalesDirective, ScaleDirective } from "ej/lineargauge.component";
//     export { EJ_DIGITALGAUGE_COMPONENTS, DigitalGaugeComponent, ItemsDirective, ItemDirective } from "ej/digitalgauge.component";
//     export { EJ_SPREADSHEET_COMPONENTS, SpreadsheetComponent, RangeSettingsDirective, RangeSettingDirective, SheetsDirective, SheetDirective } from "ej/spreadsheet.component";
//     export { EJ_DATEPICKER_COMPONENTS, DatePickerComponent, DatePickerValueAccessor } from "ej/datepicker.component";
//     export { EJ_GANTT_COMPONENTS, GanttComponent, StriplinesDirective, StriplineDirective, HolidaysDirective, HolidayDirective, SelectedCellIndexesDirective, SelectedCellIndexDirective, EditDialogFieldsDirective, EditDialogFieldDirective, AddDialogFieldsDirective, AddDialogFieldDirective, ColumnDialogFieldsDirective, ColumnDialogFieldDirective } from "ej/gantt.component";
//     export { EJ_TREEGRID_COMPONENTS, TreeGridComponent, ColumnsDirective, ColumnDirective, SelectedCellIndexesDirective, SelectedCellIndexDirective, ColumnDialogFieldsDirective, ColumnDialogFieldDirective } from "ej/treegrid.component";
//     export { EJ_COLORPICKER_COMPONENTS, ColorPickerComponent, ColorPickerValueAccessor } from "ej/colorpicker.component";
//     export { EJ_DIALOG_COMPONENTS, DialogComponent } from "ej/dialog.component";
//     export { EJ_SCROLLER_COMPONENTS, ScrollerComponent } from "ej/scroller.component";
//     export { EJ_BARCODE_COMPONENTS, BarcodeComponent } from "ej/barcode.component";
//     export { EJ_PDFVIEWER_COMPONENTS, PdfViewerComponent } from "ej/pdfviewer.component";
//     export { EJ_NUMERICTEXTBOX_COMPONENTS, NumericTextboxComponent, NumericTextboxValueAccessor } from "ej/numerictextbox.component";
//     export { EJ_CURRENCYTEXTBOX_COMPONENTS, CurrencyTextboxComponent, CurrencyTextboxValueAccessor } from "ej/currencytextbox.component";
//     export { EJ_PERCENTAGETEXTBOX_COMPONENTS, PercentageTextboxComponent, PercentageTextboxValueAccessor } from "ej/percentagetextbox.component";
//     export { EJ_TIMEPICKER_COMPONENTS, TimePickerComponent, TimePickerValueAccessor } from "ej/timepicker.component";
//     export { EJ_TOOLBAR_COMPONENTS, ToolbarComponent } from "ej/toolbar.component";
//     export { EJ_MENU_COMPONENTS, MenuComponent } from "ej/menu.component";
//     export { EJ_AUTOCOMPLETE_COMPONENTS, AutocompleteComponent, AutocompleteValueAccessor } from "ej/autocomplete.component";
//     export { EJ_MASKEDIT_COMPONENTS, MaskEditComponent, MaskEditValueAccessor } from "ej/maskedit.component";
//     export { EJ_TREEVIEW_COMPONENTS, TreeViewComponent } from "ej/treeview.component";
//     export { EJ_SCHEDULE_COMPONENTS, ScheduleComponent, ResourcesDirective, ResourceDirective } from "ej/schedule.component";
//     export { EJ_KANBAN_COMPONENTS, KanbanComponent, ColumnsDirective, ColumnDirective } from "ej/kanban.component";
//     export { EJ_RIBBON_COMPONENTS, RibbonComponent, ApplicationTabBackstageSettingsPagesDirective, PageDirective, ContentGroupsDirective, ContentGroupDirective, ContentsDirective, ContentDirective, GroupsDirective, GroupDirective, TabsDirective, TabDirective } from "ej/ribbon.component";
//     export { EJ_PIVOTGRID_COMPONENTS, PivotGridComponent } from "ej/pivotgrid.component";
//     export { EJ_RATING_COMPONENTS, RatingComponent } from "ej/rating.component";
//     export { EJ_LISTBOX_COMPONENTS, ListBoxComponent } from "ej/listbox.component";
//     export { EJ_LISTVIEW_COMPONENTS, ListViewComponent, ItemsDirective, ItemDirective } from "ej/listview.component";
//     export { EJ_ROTATOR_COMPONENTS, RotatorComponent } from "ej/rotator.component";
//     export { EJ_RTE_COMPONENTS, RTEComponent, RTEValueAccessor } from "ej/rte.component";
//     export { EJ_DROPDOWNLIST_COMPONENTS, DropDownListComponent, DropDownListValueAccessor } from "ej/dropdownlist.component";
//     export { EJ_RADIALMENU_COMPONENTS, RadialMenuComponent } from "ej/radialmenu.component";
//     export { EJ_TILEVIEW_COMPONENTS, TileViewComponent } from "ej/tileview.component";
//     export { EJ_ACCORDION_COMPONENTS, AccordionComponent } from "ej/accordion.component";
//     export { EJ_TAB_COMPONENTS, TabComponent } from "ej/tab.component";
//     export { EJ_CHECKBOX_COMPONENTS, CheckBoxComponent } from "ej/checkbox.component";
//     export { EJ_RADIOBUTTON_COMPONENTS, RadioButtonComponent, RadioButtonValueAccessor } from "ej/radiobutton.component";
//     export { EJ_TOGGLEBUTTON_COMPONENTS, ToggleButtonComponent } from "ej/togglebutton.component";
//     export { EJ_DATETIMEPICKER_COMPONENTS, DateTimePickerComponent, DateTimePickerValueAccessor } from "ej/datetimepicker.component";
//     export { EJ_PROGRESSBAR_COMPONENTS, ProgressBarComponent } from "ej/progressbar.component";
//     export { EJ_TAGCLOUD_COMPONENTS, TagCloudComponent } from "ej/tagcloud.component";
//     export { EJ_BUTTON_COMPONENTS, ButtonComponent } from "ej/button.component";
//     export { EJ_TOOLTIP_COMPONENTS, TooltipComponent } from "ej/tooltip.component";
//     export { EJ_SLIDER_COMPONENTS, SliderComponent } from "ej/slider.component";
//     export { EJ_FILEEXPLORER_COMPONENTS, FileExplorerComponent } from "ej/fileexplorer.component";
//     export { EJ_REPORTVIEWER_COMPONENTS, ReportViewerComponent } from "ej/reportviewer.component";
//     export { EJ_SPLITTER_COMPONENTS, SplitterComponent } from "ej/splitter.component";
// }
